@@ -35,13 +35,18 @@ const GLib = imports.gi.GLib;
 const Main = imports.main;
 const Format = imports.format;
 const MainWindow = imports.mainWindow;
+const Notification = imports.notification;
+const NotificationManager = imports.notificationManager;
 const Utils = imports.utils;
 const Path = imports.path;
 const Settings = imports.settings;
+const PlaceStore = imports.placeStore;
 
 // used globally
 let application = null;
 let settings = null;
+let placeStore = null;
+let notificationManager = null;
 
 const Application = new Lang.Class({
     Name: 'Application',
@@ -61,6 +66,16 @@ const Application = new Lang.Class({
         this._mainWindow.window.destroy();
     },
 
+    _initPlaceStore: function() {
+        placeStore = new PlaceStore.PlaceStore();
+        try {
+            placeStore.load();
+        } catch (e) {
+            log('Failed to parse Maps places file, ' +
+                'subsequent writes will overwrite the file!');
+        }
+    },
+
     _initAppMenu: function() {
         let builder = new Gtk.Builder();
         builder.add_from_resource('/org/gnome/maps/app-menu.ui');
@@ -85,6 +100,7 @@ const Application = new Lang.Class({
             signalHandlers: { activate: this._onQuitActivate }
         }], this);
 
+        this._initPlaceStore();
         this._initAppMenu();
     },
 
@@ -92,10 +108,21 @@ const Application = new Lang.Class({
         if (this._mainWindow)
             return;
 
-        this._mainWindow = new MainWindow.MainWindow(this);
+        let overlay = new Gtk.Overlay({ visible: true, can_focus: true });
+        notificationManager = new NotificationManager.NotificationManager(overlay);
+        this._mainWindow = new MainWindow.MainWindow(this, overlay);
         this._mainWindow.window.connect('destroy', this._onWindowDestroy.bind(this));
     },
 
+    vfunc_dbus_register: function(connection, path) {
+        this.parent(connection, path);
+        return true;
+    },
+
+    vfunc_dbus_unregister: function(connection, path) {
+        this.parent(connection, path);
+    },
+
     vfunc_activate: function() {
         this._createWindow();
         this._mainWindow.window.present();
