@@ -25,12 +25,14 @@ const Gdk = imports.gi.Gdk;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
 const Champlain = imports.gi.Champlain;
+const GObject = imports.gi.GObject;
 
 const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
 const MapView = imports.mapView;
+const LayersPopover = imports.layersPopover;
 const SearchPopup = imports.searchPopup;
 const ContextMenu = imports.contextMenu;
 const PlaceStore = imports.placeStore;
@@ -47,43 +49,37 @@ const _WINDOW_MIN_HEIGHT = 500;
 const MainWindow = new Lang.Class({
     Name: 'MainWindow',
 
-    _init: function(app) {
+    _init: function(app, overlay) {
         this._configureId = 0;
         let ui = Utils.getUIObject('main-window', [ 'app-window',
-                                                    'window-content',
                                                     'search-entry',
-                                                    'search-completion']);
+                                                    'search-completion',
+                                                    'layers-button']);
         this._searchEntry = ui.searchEntry;
         this._searchCompletion = ui.searchCompletion;
         this.window = ui.appWindow;
         this.window.application = app;
-        this._windowContent = ui.windowContent;
+        this._placeStore = Application.placeStore;
+        this._overlay = overlay;
+
+        ui.appWindow.add(this._overlay);
 
         this.mapView = new MapView.MapView();
-        ui.windowContent.add(this.mapView);
+        overlay.add(this.mapView);
 
         this.mapView.gotoUserLocation(false);
 
         this._contextMenu = new ContextMenu.ContextMenu(this.mapView);
 
-        this._initPlaces();
+        ui.layersButton.popover = new LayersPopover.LayersPopover();
+
         this._initSearchWidgets();
         this._initActions();
         this._initSignals();
         this._restoreWindowGeometry();
 
-        this._windowContent.add_overlay(new ZoomControl.ZoomControl(this.mapView));
-        this._windowContent.show_all();
-    },
-
-    _initPlaces: function() {
-        this._placeStore = new PlaceStore.PlaceStore();
-        try {
-            this._placeStore.load();
-        } catch (e) {
-            log('Failed to parse Maps places file, ' +
-                'subsequent writes will overwrite the file!');
-        }
+        this._overlay.add_overlay(new ZoomControl.ZoomControl(this.mapView));
+        this._overlay.show_all();
     },
 
     _initSearchWidgets: function() {
@@ -92,11 +88,11 @@ const MainWindow = new Lang.Class({
         this._searchPopup.connect('selected',
                                   this._onSearchPopupSelected.bind(this));
         this._searchPopup.connect('selected',
-                                  this._windowContent.grab_focus.bind(this._windowContent));
+                                  this._overlay.grab_focus.bind(this._overlay));
         this.mapView.view.connect('button-press-event',
                                   this._searchPopup.hide.bind(this._searchPopup));
         this.mapView.view.connect('button-press-event',
-                                  this._windowContent.grab_focus.bind(this._windowContent));
+                                  this._overlay.grab_focus.bind(this._overlay));
         this._searchEntry.connect('changed',
                                   this._searchPopup.hide.bind(this._searchPopup));
 
@@ -136,6 +132,11 @@ const MainWindow = new Lang.Class({
                 signalHandlers: { activate: this._onGotoUserLocationActivate }
             }
         ], this);
+
+        let action = this.window.lookup_action('goto-user-location');
+        this.mapView.geoclue.bind_property('connected',
+                                           action, 'enabled',
+                                           GObject.BindingFlags.SYNC_CREATE);
     },
 
     _initSignals: function() {
