@@ -38,14 +38,15 @@ const Sidebar = imports.sidebar;
 const Utils = imports.utils;
 const Path = imports.path;
 const MapLocation = imports.mapLocation;
-const MapSource = imports.mapSource;
 const UserLocation = imports.userLocation;
 const Geoclue = imports.geoclue;
 const _ = imports.gettext.gettext;
 
 const MapType = {
-    STREET: 'MapsStreetSource',
-    AERIAL: 'MapsAerialSource'
+    STREET:  Champlain.MAP_SOURCE_OSM_MAPQUEST,
+    AERIAL:  Champlain.MAP_SOURCE_OSM_AERIAL_MAP,
+    CYCLING: Champlain.MAP_SOURCE_OSM_CYCLE_MAP,
+    TRANSIT: Champlain.MAP_SOURCE_OSM_TRANSPORT_MAP
 };
 
 const MapMinZoom = 2;
@@ -86,6 +87,7 @@ const MapView = new Lang.Class({
             }
         }).bind(this));
 
+        this._factory = Champlain.MapSourceFactory.dup_default();
         this.setMapType(MapType.STREET);
 
 
@@ -96,15 +98,11 @@ const MapView = new Lang.Class({
     },
 
     setMapType: function(mapType) {
-        if (mapType === MapType.AERIAL)
-            this.view.map_source = MapSource.createAerialSource();
-        else
-            this.view.map_source = MapSource.createStreetSource();
+        if (this.view.map_source.get_id() === mapType)
+            return;
 
-        if (!this._attribution) {
-                this._attribution = new MapSource.AttributionLogo(this.view);
-                this.view.add_child(this._attribution);
-        }
+        let source = this._factory.create_cached_source(mapType);
+        this.view.set_map_source(source);
     },
 
     geocodeSearch: function(searchString, searchCompleteCallback) {
@@ -168,8 +166,10 @@ const MapView = new Lang.Class({
                                                     Geocode.PlaceType.UNKNOWN,
                                                     this.geoclue.location);
 
+        let selected = this._userLocation && this._userLocation.getSelected();
         this._userLocation = new UserLocation.UserLocation(place, this);
         this._userLocation.show(this._userLocationLayer);
+        this._userLocation.setSelected(selected);
         this.emit('user-location-changed');
     },
 
